# SKES Framework
###### SwiftKRAS Enterprise software | PyProject Framework

### INTRO

This framework help create and manage default project

It will help this:

* Create projects' template
* Create project from template
* Create in-project applications
* Build project to app (with PyInstaller | Completable with Windows/Unix/OS X)
* And much more in future version!

### How to install

* Windows
  * Open commandline > use `WIN (key with logo) + R`
  * print `powershell`, then press ENTER
  * in opened window use command below

`python -m pip install skes-projectframework`

* Linux
  * Open bash > press 3 keys together `Ctrl + Alt + T`
  * in opened window use command below

`python3 -m pip install skes-projectframework`

* Apple macOS X
  * Open Spotlight > press 2 keys together `CMD + Space`
  * print `Terminal.app` and start application
  * in opened window use command below

`python3 -m pip install skes-projectframework`

    Typical ERRORS
    (Q): pip finished with errors (Linux & OS X) 
    (A): you should be use admin privilege `sudo` or "brew packet manager"
